@@ -20,10 +20,10 @@ use std::fmt::Debug;
 /// Initial bucket size is set to 1
 const INITIAL_NBUCKETS: usize = 1;
 
-/// LearnedHashMap takes a model instead of an hasher for hashing indexes in the table
+/// LearnedHashMap takes a model instead of an hasher for hashing indexes in the table.
 ///
-/// Default Model for the LearndedHashMap is Linear regression
-/// In order to build a ordered HashMap, we need to make sure that the model is monotonic
+/// Default Model for the LearndedHashMap is Linear regression.
+/// In order to build a ordered HashMap, we need to make sure that the model is **monotonic**.
 #[derive(Debug, Clone)]
 pub struct LearnedHashMap<M, F> {
     hasher: LearnedHasher<M>,
@@ -31,6 +31,7 @@ pub struct LearnedHashMap<M, F> {
     items: usize,
 }
 
+/// Default for the LearndedHashMap.
 impl<M, F> Default for LearnedHashMap<M, F>
 where
     F: Float,
@@ -50,21 +51,20 @@ where
     F: Float + Default + AsPrimitive<u64> + FromPrimitive + Debug,
     M: Model<F = F> + Default + Clone,
 {
-    /// Returns a default LearnedHashMap with Model and Float type
+    /// Returns a default LearnedHashMap with Model and Float type.
     ///
     /// # Examples
     ///
     /// ```
-    /// // You can have rust code between fences inside the comments
-    /// // If you pass --test to `rustdoc`, it will even test it for you!
     /// use lsph::{LearnedHashMap, LinearModel};
     /// let map = LearnedHashMap::<LinearModel<f64>, f64>::new();
     /// ```
+    #[inline]
     pub fn new() -> Self {
         Self::default()
     }
 
-    /// Returns a default LearnedHashMap with Model and Float type
+    /// Returns a default LearnedHashMap with Model and Float type.
     ///
     /// # Arguments
     /// * `hasher` - A LearnedHasher with model
@@ -72,11 +72,10 @@ where
     /// # Examples
     ///
     /// ```
-    /// // You can have rust code between fences inside the comments
-    /// // If you pass --test to `rustdoc`, it will even test it for you!
     /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
     /// let map = LearnedHashMap::<LinearModel<f64>, f64>::with_hasher(LearnedHasher::new());
     /// ```
+    #[inline]
     pub fn with_hasher(hasher: LearnedHasher<M>) -> Self {
         Self {
             hasher,
@@ -85,7 +84,7 @@ where
         }
     }
 
-    /// Returns a default LearnedHashMap with Model and Float type
+    /// Returns a default LearnedHashMap with Model and Float type.
     ///
     /// # Arguments
     /// * `capacity` - A predefined capacity size for the LearnedHashMap
@@ -93,11 +92,10 @@ where
     /// # Examples
     ///
     /// ```
-    /// // You can have rust code between fences inside the comments
-    /// // If you pass --test to `rustdoc`, it will even test it for you!
     /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
     /// let map = LearnedHashMap::<LinearModel<f64>, f64>::with_capacity(10usize);
     /// ```
+    #[inline]
     pub fn with_capacity(capacity: usize) -> Self {
         Self {
             hasher: Default::default(),
@@ -106,7 +104,22 @@ where
         }
     }
 
-    pub fn get(&mut self, p: &(F, F)) -> Option<&Point<F>> {
+    /// Returns Option<Point<F>>  with given point data.
+    ///
+    /// # Arguments
+    /// * `p` - A array slice containing two points for querying
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
+    /// let point_data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let (mut map, points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&point_data).unwrap();
+    ///
+    /// assert_eq!(map.get(&[1., 1.]).is_some(), true);
+    /// ```
+    #[inline]
+    pub fn get(&mut self, p: &[F; 2]) -> Option<&Point<F>> {
         let hash = make_hash_point(&mut self.hasher, p) as usize;
         if hash > self.table.capacity() {
             return None;
@@ -114,39 +127,120 @@ where
         self.find_by_hash(hash, p)
     }
 
-    pub fn find_by_hash(&self, hash: usize, p: &(F, F)) -> Option<&Point<F>> {
+    /// Returns Option<Point<F>> by hash index, if it exists in the map.
+    ///
+    /// # Arguments
+    /// * `hash` - An usize hash value
+    /// * `p` - A array slice containing two points for querying
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
+    /// let point_data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let (mut map, points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&point_data).unwrap();
+    ///
+    /// assert_eq!(map.find_by_hash(0, &[1., 1.]).is_some(), true);
+    /// assert_eq!(map.find_by_hash(1, &[1., 1.]).is_none(), true);
+    /// ```
+    #[inline]
+    pub fn find_by_hash(&self, hash: usize, p: &[F; 2]) -> Option<&Point<F>> {
         self.table[hash]
             .iter()
-            .find(|&ep| ep.x == p.0 && ep.y == p.1)
+            .find(|&ep| ep.x == p[0] && ep.y == p[1])
     }
 
+    /// Returns bool.
+    ///
+    /// # Arguments
+    /// * `p` - A array slice containing two points for querying
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
+    /// let point_data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let (mut map, points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&point_data).unwrap();
+    ///
+    /// assert_eq!(map.contains_points(&[1., 1.]), true);
+    /// assert_eq!(map.contains_points(&[0., 1.]), false);
+    /// ```
     #[inline]
-    pub fn contains_key(&mut self, key: &(F, F)) -> bool {
-        self.get(key).is_some()
+    pub fn contains_points(&mut self, p: &[F; 2]) -> bool {
+        self.get(p).is_some()
     }
 
+    /// Returns Option<Point<F>> if the map contains a point and successful remove it from the map.
+    ///
+    /// # Arguments
+    /// * `p` - A Point data
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
+    /// let point_data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let (mut map, points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&point_data).unwrap();
+    ///
+    /// let p = points[0];
+    /// assert_eq!(map.remove(&p).unwrap(), p);
+    /// ```
     #[inline]
     pub fn remove(&mut self, p: &Point<F>) -> Option<Point<F>> {
-        let hash = make_hash_point(&mut self.hasher, &(p.x, p.y));
+        let hash = make_hash_point(&mut self.hasher, &[p.x, p.y]);
         self.items -= 1;
         self.table.remove_entry(hash, *p)
     }
 
+    /// Returns usize length.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
+    /// let point_data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let (mut map, points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&point_data).unwrap();
+    ///
+    /// assert_eq!(map.len(), 4);
+    /// ```
     #[inline]
     pub fn len(&self) -> usize {
         self.table.len()
     }
 
+    /// Returns usize number of items.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
+    /// let point_data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let (mut map, points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&point_data).unwrap();
+    ///
+    /// assert_eq!(map.items(), 4);
+    /// ```
     #[inline]
     pub fn items(&self) -> usize {
         self.items
     }
 
+    /// Returns bool if the map is empty.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
+    /// let point_data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let (mut map, points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&point_data).unwrap();
+    ///
+    /// assert_eq!(map.is_empty(), false);
+    /// ```
     #[inline]
     pub fn is_empty(&self) -> bool {
         self.items == 0
     }
 
+    /// Resize the map if needed, it will initialize the map to the INITIAL_NBUCKETS, otherwise it will double the capacity if table is not empty.
     fn resize(&mut self) {
         let target_size = match self.table.len() {
             0 => INITIAL_NBUCKETS,
@@ -155,13 +249,14 @@ where
         self.resize_with_capacity(target_size);
     }
 
+    /// Resize the map if needed, it will resize the map to desired capacity.
     #[inline(never)]
     fn resize_with_capacity(&mut self, target_size: usize) {
         let mut new_table = Table::with_capacity(target_size);
         new_table.extend((0..target_size).map(|_| Bucket::new()));
 
         for p in self.table.iter_mut().flat_map(|bucket| bucket.drain(..)) {
-            let hash = make_hash_point(&mut self.hasher, &(p.x, p.y)) as usize;
+            let hash = make_hash_point(&mut self.hasher, &[p.x, p.y]) as usize;
             new_table[hash].push(p);
         }
 
@@ -190,10 +285,11 @@ where
     ///
     /// * `top_right` - A tuple containing a pair of points that represent the top right of the
     /// range.
+    #[inline]
     pub fn range_search(
         &mut self,
-        bottom_left: &(F, F),
-        top_right: &(F, F),
+        bottom_left: &[F; 2],
+        top_right: &[F; 2],
     ) -> Option<Vec<Point<F>>> {
         let mut right_hash = make_hash_point(&mut self.hasher, top_right) as usize;
         if right_hash > self.table.capacity() {
@@ -207,10 +303,10 @@ where
         for i in left_hash..=right_hash {
             let bucket = &self.table[i];
             for item in bucket.iter() {
-                if item.x >= bottom_left.0
-                    && item.x <= top_right.0
-                    && item.y >= bottom_left.1
-                    && item.y <= top_right.1
+                if item.x >= bottom_left[0]
+                    && item.x <= top_right[0]
+                    && item.y >= bottom_left[1]
+                    && item.y <= top_right[1]
                 {
                     result.push(*item);
                 }
@@ -222,25 +318,53 @@ where
         Some(result)
     }
 
-    pub fn radius_range(&mut self, query_point: &(F, F), radius: F) -> Option<Vec<Point<F>>> {
+    /// Returns Option<Vec<Point<F>>> if points are found in the map with given range
+    ///
+    /// # Arguments
+    /// * `query_point` - A Point data for querying
+    /// * `radius` - A radius value
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel, LearnedHasher};
+    /// let point_data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let (mut map, points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&point_data).unwrap();
+    ///
+    /// assert_eq!(map.range_search(&[0., 0.], &[3., 3.]).is_some(), true);
+    /// ```
+    #[inline]
+    pub fn radius_range(&mut self, query_point: &[F; 2], radius: F) -> Option<Vec<Point<F>>> {
         self.range_search(
-            &(query_point.0 - radius, query_point.1 - radius),
-            &(query_point.0 + radius, query_point.1 + radius),
+            &[query_point[0] - radius, query_point[1] - radius],
+            &[query_point[0] + radius, query_point[1] + radius],
         )
     }
 
+    /// Find the local minimum distance between query points and cadidates neighbors, then store
+    /// the cadidates neighbors in the min_heap.
+    ///
+    ///
+    /// # Arguments
+    /// * `heap` - mutable borrow of an BinaryHeap
+    /// * `local_hash` - A hash index of local bucket
+    /// * `query_point` - A Point data
+    /// * `min_d` - minimum distance
+    /// * `nearest_neighbor` - mutable borrow of an point data, which is the nearest neighbor at
+    /// search index bucket
+    #[inline]
     fn local_min_heap(
         &self,
         heap: &mut BinaryHeap<NearestNeighborState<F>>,
         local_hash: u64,
-        query_point: &(F, F),
+        query_point: &[F; 2],
         min_d: &mut F,
         nearest_neighbor: &mut Point<F>,
     ) {
         let bucket = &self.table[local_hash as usize];
         if !bucket.is_empty() {
             for p in bucket.iter() {
-                let d = Euclidean::distance(query_point, &(p.x, p.y));
+                let d = Euclidean::distance(query_point, &[p.x, p.y]);
                 heap.push(NearestNeighborState {
                     distance: d,
                     point: *p,
@@ -260,11 +384,17 @@ where
         }
     }
 
-    fn horizontal_distance(&mut self, query_point: &(F, F), hash: u64) -> F {
+    /// Calculates the horizontal distance between query_point and bucket at index with given hash.
+    ///
+    /// # Arguments
+    /// * `hash` - A hash index of the bucket
+    /// * `query_point` - A Point data
+    #[inline]
+    fn horizontal_distance(&mut self, query_point: &[F; 2], hash: u64) -> F {
         let x = unhash(&mut self.hasher, hash);
         match self.hasher.sort_by_x() {
-            true => Euclidean::distance(&(query_point.0, F::zero()), &(x, F::zero())),
-            false => Euclidean::distance(&(query_point.1, F::zero()), &(x, F::zero())),
+            true => Euclidean::distance(&[query_point[0], F::zero()], &[x, F::zero()]),
+            false => Euclidean::distance(&[query_point[1], F::zero()], &[x, F::zero()]),
         }
     }
 
@@ -287,7 +417,8 @@ where
     ///
     /// * `query_point` - A tuple containing a pair of points for querying
     ///
-    pub fn nearest_neighbor(&mut self, query_point: &(F, F)) -> Option<Point<F>> {
+    #[inline]
+    pub fn nearest_neighbor(&mut self, query_point: &[F; 2]) -> Option<Point<F>> {
         let mut hash = make_hash_point(&mut self.hasher, query_point);
         let max_capacity = self.table.capacity() as u64;
 
@@ -372,6 +503,50 @@ where
     F: Float + AsPrimitive<u64> + FromPrimitive + Default + Debug + Sum,
     M: Model<F = F> + Default + Clone,
 {
+    /// Returns a default LearnedHashMap with Model and Float type
+    ///
+    /// # Arguments
+    /// * `data` - A Vec<[F; 2]> of 2d points for the map
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel};
+    /// let data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let map = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&data);
+    /// ```
+    #[inline]
+    pub fn with_data(data: &Vec<[F; 2]>) -> Result<(Self, Vec<Point<F>>), Error> {
+        use crate::helper::convert_to_points;
+        let mut map = LearnedHashMap::with_capacity(data.len());
+        let mut ps = convert_to_points(data).unwrap();
+        match map.batch_insert(&mut ps) {
+            Ok(()) => Ok((map, ps)),
+            Err(err) => Err(err),
+        }
+    }
+
+    /// Insert a point into the map.
+    ///
+    /// # Arguments
+    /// * `p` - A Point<F> with float number
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel, Point};
+    /// let a: Point<f64> = Point::new(1, 0., 1.);
+    /// let b: Point<f64> = Point::new(2, 1., 0.);
+
+    /// let mut map = LearnedHashMap::<LinearModel<f64>, f64>::new();
+    /// map.insert(a);
+    /// map.insert(b);
+
+    /// assert_eq!(map.items(), 2);
+    /// assert_eq!(map.get(&[0., 1.]).unwrap(), &a);
+    /// assert_eq!(map.get(&[1., 0.]).unwrap(), &b);
+    /// ```
+    #[inline]
     pub fn insert(&mut self, p: Point<F>) -> Option<Point<F>> {
         // Resize if the table is empty or 3/4 size of the table is full
         if self.table.is_empty() || self.items() > 3 * self.table.len() / 4 {
@@ -387,10 +562,14 @@ where
         self.insert_with_axis(p_value, p)
     }
 
+    /// Insert a point into the map along the given axis.
+    ///
+    /// # Arguments
+    /// * `p_value` - A float number represent the key of a 2d point
     #[inline]
     fn insert_with_axis(&mut self, p_value: F, p: Point<F>) -> Option<Point<F>> {
         let mut insert_index = 0;
-        let hash = make_hash_point::<M, F>(&mut self.hasher, &(p.x, p.y)) as usize;
+        let hash = make_hash_point::<M, F>(&mut self.hasher, &[p.x, p.y]) as usize;
         let bucket = &mut self.table[hash];
         if self.hasher.sort_by_x() {
             // Get index from the hasher
@@ -417,10 +596,18 @@ where
         None
     }
 
+    /// Fit the input data into the model of the hasher. Returns Error if error occurred during
+    /// model fitting.
+    ///
+    /// # Arguments
+    /// * `data` - A list of tuple of floating number
+    #[inline]
     pub fn model_fit(&mut self, data: &[(F, F)]) -> Result<(), Error> {
         self.hasher.model.fit_tuple(data)
     }
 
+    /// Inner function for batch insert
+    #[inline]
     fn _batch_insert_inner(&mut self, ps: &[Point<F>]) {
         // Allocate table capacity before insert
         let n = ps.len();
@@ -430,6 +617,21 @@ where
         }
     }
 
+    /// Batch insert a batch of 2d data into the map.
+    ///
+    /// # Arguments
+    /// * `ps` - A list of point number
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use lsph::{LearnedHashMap, LinearModel};
+    /// let point_data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+    /// let (mut map, points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&point_data).unwrap();
+    ///
+    /// assert_eq!(map.get(&[1., 1.]).is_some(), true);
+    /// ```
+    #[inline]
     pub fn batch_insert(&mut self, ps: &mut [Point<F>]) -> Result<(), Error> {
         // Select suitable axis for training
         use crate::geometry::Axis;
@@ -577,42 +779,23 @@ mod tests {
 
     #[test]
     fn insert() {
-        let a: Point<f64> = Point {
-            id: 1,
-            x: 0.,
-            y: 1.,
-        };
-
-        let b: Point<f64> = Point {
-            id: 2,
-            x: 1.,
-            y: 0.,
-        };
+        let a: Point<f64> = Point::new(1, 0., 1.);
+        let b: Point<f64> = Point::new(2, 1., 0.);
 
         let mut map = LearnedHashMap::<LinearModel<f64>, f64>::new();
         map.insert(a);
         map.insert(b);
 
         assert_eq!(map.items(), 2);
-        assert_eq!(map.get(&(0., 1.)).unwrap(), &a);
-        assert_eq!(map.get(&(1., 0.)).unwrap(), &b);
+        assert_eq!(map.get(&[0., 1.]).unwrap(), &a);
+        assert_eq!(map.get(&[1., 0.]).unwrap(), &b);
     }
 
     #[test]
     fn insert_repeated() {
         let mut map = LearnedHashMap::<LinearModel<f64>, f64>::new();
-        let a: Point<f64> = Point {
-            id: 1,
-            x: 0.,
-            y: 1.,
-        };
-
-        let b: Point<f64> = Point {
-            id: 2,
-            x: 0.,
-            y: 1.,
-        };
-
+        let a: Point<f64> = Point::new(1, 0., 1.);
+        let b: Point<f64> = Point::new(2, 1., 0.);
         let res = map.insert(a);
         assert_eq!(map.items(), 1);
         assert_eq!(res, None);
@@ -622,34 +805,21 @@ mod tests {
         assert_eq!(res, None);
     }
 
+    #[test]
+    fn with_data() {
+        let data = vec![[1., 1.], [2., 1.], [3., 2.], [4., 4.]];
+        let (mut map, _points) = LearnedHashMap::<LinearModel<f64>, f64>::with_data(&data).unwrap();
+        assert_eq!(map.get(&[1., 1.]).is_some(), true);
+    }
+
     #[test]
     fn fit_batch_insert() {
         let mut data: Vec<Point<f64>> = vec![
-            Point {
-                id: 1,
-                x: 1.,
-                y: 1.,
-            },
-            Point {
-                id: 2,
-                x: 3.,
-                y: 1.,
-            },
-            Point {
-                id: 3,
-                x: 2.,
-                y: 1.,
-            },
-            Point {
-                id: 4,
-                x: 3.,
-                y: 2.,
-            },
-            Point {
-                id: 5,
-                x: 5.,
-                y: 1.,
-            },
+            Point::new(1, 1., 1.),
+            Point::new(2, 3., 1.),
+            Point::new(3, 2., 1.),
+            Point::new(4, 3., 2.),
+            Point::new(5, 5., 1.),
         ];
         let mut map = LearnedHashMap::<LinearModel<f64>, f64>::new();
         map.batch_insert(&mut data).unwrap();
@@ -657,98 +827,41 @@ mod tests {
 
         assert_delta!(1.02272, map.hasher.model.coefficient, 0.00001);
         assert_delta!(-0.86363, map.hasher.model.intercept, 0.00001);
-        assert_eq!(
-            Some(&Point {
-                id: 1,
-                x: 1.,
-                y: 1.,
-            }),
-            map.get(&(1., 1.))
-        );
-        assert_eq!(
-            Some(&Point {
-                id: 2,
-                x: 3.,
-                y: 1.,
-            }),
-            map.get(&(3., 1.))
-        );
-        assert_eq!(
-            Some(&Point {
-                id: 5,
-                x: 5.,
-                y: 1.,
-            }),
-            map.get(&(5., 1.))
-        );
+        assert_eq!(Some(&Point::new(1, 1., 1.)), map.get(&[1., 1.]));
+        assert_eq!(Some(&Point::new(2, 3., 1.,)), map.get(&[3., 1.]));
+        assert_eq!(Some(&Point::new(5, 5., 1.)), map.get(&[5., 1.]));
 
-        assert_eq!(None, map.get(&(5., 2.)));
-        assert_eq!(None, map.get(&(2., 2.)));
-        assert_eq!(None, map.get(&(50., 10.)));
-        assert_eq!(None, map.get(&(500., 100.)));
+        assert_eq!(None, map.get(&[5., 2.]));
+        assert_eq!(None, map.get(&[2., 2.]));
+        assert_eq!(None, map.get(&[50., 10.]));
+        assert_eq!(None, map.get(&[500., 100.]));
     }
 
     #[test]
     fn range_search() {
         let mut data: Vec<Point<f64>> = vec![
-            Point {
-                id: 1,
-                x: 1.,
-                y: 1.,
-            },
-            Point {
-                id: 2,
-                x: 2.,
-                y: 2.,
-            },
-            Point {
-                id: 3,
-                x: 3.,
-                y: 3.,
-            },
-            Point {
-                id: 4,
-                x: 4.,
-                y: 4.,
-            },
-            Point {
-                id: 5,
-                x: 5.,
-                y: 5.,
-            },
+            Point::new(1, 1., 1.),
+            Point::new(2, 2., 2.),
+            Point::new(3, 3., 3.),
+            Point::new(4, 4., 4.),
+            Point::new(5, 5., 5.),
         ];
         let mut map = LearnedHashMap::<LinearModel<f64>, f64>::new();
         map.batch_insert(&mut data).unwrap();
         // dbg!(&map);
 
         let found: Vec<Point<f64>> = vec![
-            Point {
-                id: 1,
-                x: 1.,
-                y: 1.,
-            },
-            Point {
-                id: 2,
-                x: 2.,
-                y: 2.,
-            },
-            Point {
-                id: 3,
-                x: 3.,
-                y: 3.,
-            },
+            Point::new(1, 1., 1.),
+            Point::new(2, 2., 2.),
+            Point::new(3, 3., 3.),
         ];
 
-        assert_eq!(Some(found), map.range_search(&(1., 1.), &(3.5, 3.)));
+        assert_eq!(Some(found), map.range_search(&[1., 1.], &[3.5, 3.]));
 
-        let found: Vec<Point<f64>> = vec![Point {
-            id: 1,
-            x: 1.,
-            y: 1.,
-        }];
+        let found: Vec<Point<f64>> = vec![Point::new(1, 1., 1.)];
 
-        assert_eq!(Some(found), map.range_search(&(1., 1.), &(3., 1.)));
-        assert_eq!(None, map.range_search(&(4., 2.), &(5., 3.)));
+        assert_eq!(Some(found), map.range_search(&[1., 1.], &[3., 1.]));
+        assert_eq!(None, map.range_search(&[4., 2.], &[5., 3.]));
     }
 
     #[test]
@@ -770,7 +883,7 @@ mod tests {
                 }
             }
             let map_nearest = map
-                .nearest_neighbor(&(sample_point.x, sample_point.y))
+                .nearest_neighbor(&[sample_point.x, sample_point.y])
                 .unwrap();
             assert_eq!(nearest.unwrap(), &map_nearest);
             i = i + 1;
